@@ -407,7 +407,14 @@ MainWindow::~MainWindow()
 void MainWindow::setCurrentPreset(QDomNode node)
 {
   QDomNode command = node.namedItem("command");
-  _commandEditor->setPlainText(command.firstChild().toText().data().trimmed());
+  QString text = command.firstChild().toText().data().trimmed();
+  if (text == "_none_") {
+    _commandEditor->clear();
+    _commandEditor->setEnabled(false);
+  } else {
+    _commandEditor->setEnabled(true);
+    _commandEditor->setPlainText(text);
+  }
   _currentPresetNode = node;
   if (_displayMode == FullScreen) {
     _fullScreenWidget->commandParamsWidget()->saveValuesInDOM();
@@ -422,10 +429,10 @@ void MainWindow::setCurrentPreset(QDomNode node)
 void MainWindow::showOneSourceImage()
 {
   _currentSource->capture();
-  IplImage * image = _currentSource->image();
+  cv::Mat * image = _currentSource->image();
   if (image) {
     _imageView->imageMutex().lock();
-    QSize size(image->width, image->height);
+    QSize size(image->cols, image->rows);
     if (_imageView->image().size() != size) {
       _imageView->image() = QImage(size, QImage::Format_RGB888);
     }
